@@ -14,7 +14,7 @@
 
 from django.template.defaultfilters import title
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import tables
@@ -57,8 +57,7 @@ class TaskTable(tables.DataTable):
 
     def getHoverHelp(data):
         if hasattr(data, 'state_info') and data.state_info:
-
-                return {'title': data.state_info}
+            return {'title': data.state_info}
 
     STATE_STATUS_CHOICES = (
         ("success", True),
